##  Overview
This guide serves as a getting-started playbook for building and enriching your IT component inventory in SAP LeanIX Technology Risk and Compliance.
You will learn :
  * What options are available to bring IT components into your workspace
  * How to avoid duplicates and maintain consistent data
  * How to enrich IT component fact sheets with standardized information from the reference catalog
  * How SAP LeanIX automatically links IT components with related providers, categories, and dependencies to create a complete and reliable technology landscape


This overview helps you understand all available methods for building your inventory, so you can make use of the methods that suit your needs.
